<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;

class AgendamentoRecursosFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getAgendamentoRecursoCont()
    {
        $sql = "SELECT
                    AGEN.NRAGENDRECURSOCONT,
                    AGEN.NRSEQCONTRATO,
                    TO_CHAR(AGEN.DTINIAGENDAMENTO, 'DD/MM/YYYY') AS DTINIAGENDAMENTO,
                    TO_CHAR(AGEN.DTFIMAGENDAMENTO, 'DD/MM/YYYY') AS DTFIMAGENDAMENTO,
                    CONT.NRPARCNEGOCIO,
                    PARC.NMSECUNDARIPARC,
                    CONT.NRCONTRATOFCT,
                    CONT.DSREFERENCIACONT,
                    AGEN.NRESTRUTURAM,
                    LOCAL.NMESTRUTURAM,
                    AGEN.QTTOLERANCIARAIO,
                    AGEN.NRORG,
                    AGEN.IDATIVO,
                    AGEN.DTINCLUSAO,
                    AGEN.NRORGINCLUSAO,
                    AGEN.CDOPERINCLUSAO,
                    AGEN.DTULTATU,
                    AGEN.NRORGULTATU,
                    AGEN.CDOPERULTATU
                FROM
                    FCT_AGENDRECURSOCONT AGEN
                    LEFT JOIN FCT_CONTRATO         CONT ON AGEN.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                                                AND AGEN.NRORG = CONT.NRORG
                    LEFT JOIN PARCNEGOCIO          PARC ON PARC.NRPARCNEGOCIO = CONT.NRPARCNEGOCIO
                                                AND PARC.NRORG = CONT.NRORG
                    LEFT JOIN ESTRUTURAM           LOCAL ON AGEN.NRESTRUTURAM = LOCAL.NRESTRUTURAM
                                                AND AGEN.NRORG = LOCAL.NRORG
                ORDER BY DTINIAGENDAMENTO DESC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getContratosAgendRecurso()
    {
        $sql = "SELECT
                    NRSEQCONTRATO,
                    NRCONTRATOFCT,
                    DSREFERENCIACONT,
                    NRCONTRATOFCT || ' | ' || DSREFERENCIACONT AS DESCRICACAOCONTRATO
                FROM
                    FCT_CONTRATO
                WHERE
                    IDATIVO = 'S'";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getRelacEstruturaCont($param)
    {
        $sql = "SELECT DISTINCT
                    REL.NRESTRUTURAM,
                    EST.NMESTRUTURAM,
                    REL.NRORG
                FROM
                        FCT_RELACESTRUTURACONT REL
                    JOIN ESTRUTURAM EST ON REL.NRESTRUTURAM = EST.NRESTRUTURAM
                                        AND REL.NRORG = EST.NRORG
                WHERE
                    ( ( REL.NRSEQCONTRATO = :NRSEQCONTRATO )
                    OR ( :NRSEQCONTRATO IS NULL ) )";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $param);
    }

    public function getRecursosAgendCont($params)
    {
        $sql = "SELECT
                    RECU.HRINTERVALO,
                    RECU.NRRECURSOSAGENDCONT,
                    RECU.NRAGENDRECURSOCONT,
                    RECU.NRITEMOCONTRATO,
                    ITEM.NMITEMCONTRATO,
                    TO_CHAR(RECU.DTINIAGENDRECURSO, 'DD/MM/YYYY') AS DTINIAGENDRECURSO,
                    TO_CHAR(RECU.DTFIMAGENDRECURSO, 'DD/MM/YYYY') AS DTFIMAGENDRECURSO,
                    RECU.IDTPRECURSO,
                    RECU.IDESCALATRAB,
                    RECU.HRJORNADADIARIA,
                    RECU.HRDESCANSO,
                    RECU.CDPRODUTO,
                    RECU.NRPARCNEPESSOA,
                    RECU.CDEMPRESA,
                    RECU.CDBEMATIVO,
                    FCT_VIEW_RECURSOS.NMRECURSO,
                    FCT_VIEW_RECURSOS.CODRECURSO,
                    FCT_VIEW_RECURSOS.CHAVE,
                    RECU.CDFILIALPED,
                    RECU.NRPEDIDO,
                    RECU.NRITEMPED,
                    RECU.NRRECURSOSUPERIOR,
                    VIEW_SUPERIOR.NMRECURSO                       AS NMRECURSOSUPERIOR,
                    RECU.IDMOTIVOAGENDAMENTO,
                    RECU.IDSITUARECGEND,
                    RECU.DSATIVIDADESAGEND,
                    RECU.HRPRIMEIRAENTRADA,
                    RECU.HRPRIMEIRASAIDA,
                    RECU.HRSEGUNDAENTRADA,
                    RECU.HRSEGUNDASAIDA,
                    RECU.NRTEMPOTOLERANCIA,
                    RECU.IDREPETDOMINGO,
                    RECU.IDREPETSEGUNDA,
                    RECU.IDREPETTERCA,
                    RECU.IDREPETQUARTA,
                    RECU.IDREPETQUINTA,
                    RECU.IDREPETSEXTA,
                    RECU.IDREPETSABADO,
                    RECU.NRORG,
                    RECU.IDATIVO,
                    RECU.DTINCLUSAO,
                    RECU.NRORGINCLUSAO,
                    RECU.CDOPERINCLUSAO,
                    RECU.DTULTATU,
                    RECU.NRORGULTATU,
                    RECU.CDOPERULTATU,
                    RECU.IDHORAEXTRA,
                    RECU.IDDESCANSOREMU,
                    RECU.IDALTERACAOEQUIPE,
                    RECU.NRRECURSOALTEQUIPE,
                    VIEW_REC_ORIGEM.NMRECURSO                     AS NMRECURSOALTEQUIPE,
                    RECU.DSJUSTIFICAALTEQUIPE
                FROM
                    FCT_RECURSOSAGENDCONT RECU
                    LEFT JOIN FCT_RECURSOSAGENDCONT RECUSUP ON RECU.NRRECURSOSUPERIOR = RECUSUP.NRRECURSOSAGENDCONT
                                                            AND RECU.NRORG = RECUSUP.NRORG
                    LEFT JOIN FCT_VIEW_RECURSOS ON NVL(TO_CHAR(RECU.NRPARCNEPESSOA),
                                                        NVL(RECU.CDBEMATIVO, RECU.CDPRODUTO)) = FCT_VIEW_RECURSOS.CHAVE
                                                AND RECU.IDTPRECURSO = FCT_VIEW_RECURSOS.CDTIPO
                                                AND NVL(RECU.CDEMPRESA, - 1) = NVL(FCT_VIEW_RECURSOS.CDEMPRESA, - 1)
                                                AND RECU.NRORG = FCT_VIEW_RECURSOS.NRORG
                    LEFT JOIN FCT_VIEW_RECURSOS     VIEW_SUPERIOR ON NVL(TO_CHAR(RECUSUP.NRPARCNEPESSOA),
                                                                        NVL(RECUSUP.CDBEMATIVO, RECUSUP.CDPRODUTO)) = VIEW_SUPERIOR.CHAVE
                                                                AND RECUSUP.IDTPRECURSO = VIEW_SUPERIOR.CDTIPO
                                                                AND NVL(RECUSUP.CDEMPRESA, - 1) = NVL(VIEW_SUPERIOR.CDEMPRESA, - 1)
                                                                AND RECUSUP.NRORG = VIEW_SUPERIOR.NRORG
                    LEFT JOIN FCT_RECURSOSAGENDCONT RECORIGEM ON RECU.NRRECURSOALTEQUIPE = RECORIGEM.NRRECURSOSAGENDCONT
                                                                AND RECU.NRORG = RECORIGEM.NRORG
                    LEFT JOIN FCT_VIEW_RECURSOS     VIEW_REC_ORIGEM ON NVL(TO_CHAR(RECORIGEM.NRPARCNEPESSOA),
                                                                        NVL(RECORIGEM.CDBEMATIVO, RECORIGEM.CDPRODUTO)) = VIEW_REC_ORIGEM.CHAVE
                                                                AND RECORIGEM.IDTPRECURSO = VIEW_REC_ORIGEM.CDTIPO
                                                                AND NVL(RECORIGEM.CDEMPRESA, - 1) = NVL(VIEW_REC_ORIGEM.CDEMPRESA, - 1)
                                                                AND RECORIGEM.NRORG = VIEW_REC_ORIGEM.NRORG
                    LEFT JOIN FCT_ITEMCONTRATO      ITEM ON RECU.NRITEMOCONTRATO = ITEM.NRITEMOCONTRATO
                                                    AND RECU.NRORG = ITEM.NRORG
                WHERE RECU.NRAGENDRECURSOCONT = :NRAGENDRECURSOCONT";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    } 

    public function getItemContAgendRecurso($param)
    {
        $sql = "SELECT
                    CDHABILITSERV,
                    CDPRODUTO,
                    CDSERVORCA,
                    SGUNIDADE,
                    NMITEMCONTRATO,
                    QTITEMCONTRATO,
                    CDPRECBASESERV,
                    CDTPMEDIDASERV,
                    QTMEDIDACONTR,
                    IDFATURACONTR,
                    CDMODPGTO,
                    NRGRUPOFATURA,
                    QTTEMPOSERV,
                    IDUNIDTEMPOSERV,
                    IDITEMATIVO,
                    VRUNITITEMCONT,
                    VRTOTITEMCONT,
                    NRORG,
                    IDATIVO,
                    DTINCLUSAO,
                    DTULTATU,
                    NRORGINCLUSAO,
                    CDOPERINCLUSAO,
                    NRORGULTATU,
                    CDOPERULTATU,
                    IDMULTMEDVRTOT,
                    DTINICFATCONTR,
                    IDADICITEMCONT,
                    IDADICCOBRCONT,
                    NRITEMCONTRATOPAI,
                    IDBLOQSEMMEDIC,
                    IDFATURAITEM,
                    IDTPDESCONTO,
                    VRDESCONTO,
                    NRITEMOCONTRATO,
                    NRSEQCONTRATO,
                    QTPARCELASFATU,
                    NRDIAVENCPARCELASFATU,
                    QTMEDIDACALCULADA,
                    CDTPMEDIDAVARIAVEL,
                    NRESTRUTURAM,
                    TXOBSITCONTRATO,
                    NRMOEDA,
                    CDGRUPSERVINTTECFOOD,
                    HRINIPREPSERVINTTECFOOD,
                    DSLOTEFATURAMENTO
                FROM
                    FCT_ITEMCONTRATO
                WHERE
                        NRSEQCONTRATO = :NRSEQCONTRATO
                    AND NRORG = :NRORG";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $param);
    }

    public function getRecursoAgendCont($param)
    {
        $sql = "";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $param);
    }
}